package CSV::Examples;

our $DATE = '2019-05-12'; # DATE
our $VERSION = '0.003'; # VERSION

1;
# ABSTRACT: Example CSV files

__END__

=pod

=encoding UTF-8

=head1 NAME

CSV::Examples - Example CSV files

=head1 VERSION

This document describes version 0.003 of CSV::Examples (from Perl distribution CSV-Examples), released on 2019-05-12.

=head1 DESCRIPTION

This distribution contains various examples of CSV files in its per-dist share
dir.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/CSV-Examples>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-CSV-Examples>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=CSV-Examples>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

Some modules to parse CSV: L<Text::CSV_XS>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2019 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
